/*!
 * \file 
 * \brief Gyro Click example
 * 
 * # Description
 * This example displays values of Gyro sensor (x, y, z axis).
 *
 * The demo application is composed of two sections :
 * 
 * ## Application Init 
 * Initialization driver, initialize L3GD20 register and start write log.
 * 
 * ## Application Task  
 * (code snippet) This is a example which demonstrates the use of Gyro Click board.
 *  Measured Gyro coordinates ( X-axis, Y-axis, Z-axis ) and temperature in degrees C are being sent
 *  to the Usart Terminal where you can track their changes.
 *  All data logs on usb uart for every 2 sec.
 * 
 * 
 * \author MikroE Team
 *
 */
// ------------------------------------------------------------------- INCLUDES

#include "board.h"
#include "log.h"
#include "gyro.h"

// ------------------------------------------------------------------ VARIABLES

static gyro_t gyro;
static log_t logger;
static int16_t gyrox;
static int16_t gyroy;
static int16_t gyroz;
static float temperature;

// ------------------------------------------------------ APPLICATION FUNCTIONS

void application_init ( void )
{
    log_cfg_t log_cfg;
    gyro_cfg_t cfg;

    //  Logger initialization.

    log_cfg.level = LOG_LEVEL_DEBUG;
    LOG_MAP_USB_UART( log_cfg );
    log_init( &logger, &log_cfg );
    log_info( &logger, "---- Application Init ----" );

    //  Click initialization.

    gyro_cfg_setup( &cfg );
    GYRO_MAP_MIKROBUS( cfg, MIKROBUS_1 );
    gyro_init( &gyro, &cfg );
    gyro_default_cfg ( &gyro);
}

void application_task ( void )
{
    //  Task implementation.

    gyro_read_gyro(  &gyro, &gyrox,  &gyroy, &gyroz );
    temperature = gyro_read_temperature( &gyro );

    log_printf( &logger, " Axis X : %d \r\n", gyrox );
    log_printf( &logger, " Axis Y : %d \r\n", gyroy );
    log_printf( &logger, " Axis Z : %d \r\n", gyroz );
    log_printf( &logger, " Temp.: %.2f C\r\n", temperature );

    Delay_ms( 2000 );
}

void main ( void )
{
    application_init( );

    for ( ; ; )
    {
        application_task( );
    }
}


// ------------------------------------------------------------------------ END
